@@ -6,11 +6,14 @@ use warnings;
 use strict;
 use Log::Log4perl;
 use Daemon::Daemonize qw/:all/;
+use Tapper::Config;
 
 use Tapper::Installer::Base;
 
 BEGIN {
-        Log::Log4perl::init('/etc/log4perl.cfg');
+        Tapper::Config::_switch_context; # reload config
+        my $l4p_cfg = Tapper::Config->subconfig->{files}{log4perl_cfg};
+        Log::Log4perl::init($l4p_cfg);
 }
 
 # don't use the config of the last simnow session
@@ -20,7 +23,7 @@ system("rm","/etc/tapper") if -e "/etc/tapper";
 Daemon::Daemonize->daemonize(close => "std");
 
 
-my $client = new Tapper::Installer::Base;
+my $client = Tapper::Installer::Base->new();
 $client->system_install("simnow");
 
 __END__
@@ -62,7 +65,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2022 by Advanced Micro Devices, Inc.
+This software is Copyright (c) 2024 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
